==> dasu_4.11.jar: edu/northwestern/dasu/measurement/scheduler/UnlimitedQueue.java <==
/**
 * Dasu Project
 *
 * File:         Queue.java
 * RCS:          $Id: Queue.java,v 1.0 Apr 17, 2012 12:22:52 PM mas939 Exp $
 * Description:  Queue class (see below)
 * Author:       John Otto
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 17, 2012 at 12:22:52 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement.scheduler
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.measurement.scheduler;

/**
 * @author John Otto &lt;jotto@eecs.northwestern.edu&gt;
 *
 * The Queue class ...
 */
public class UnlimitedQueue extends Queue {
	// A basic, unlimited queue

	public boolean schedulable() {
		return true;
	}

	public boolean admittable() {
		return true;
	}

	protected void schedule() {
	}
	
}

==> dasu_5.31.jar: edu/northwestern/dasu/measurement/scheduler/UnlimitedQueue.java <==
/**
 * Dasu Project
 *
 * File:         Queue.java
 * RCS:          $Id: Queue.java,v 1.0 Apr 17, 2012 12:22:52 PM mas939 Exp $
 * Description:  Queue class (see below)
 * Author:       John Otto
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 17, 2012 at 12:22:52 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement.scheduler
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.measurement.scheduler;

import edu.northwestern.dasu.measurement.tasks.DasuSubTask;
import edu.northwestern.dasu.measurement.tasks.DasuTask;

/**
 * @author John Otto &lt;jotto@eecs.northwestern.edu&gt;
 *
 * The Queue class ...
 */
public class UnlimitedQueue<T extends DasuTask<S>, S extends DasuSubTask> extends Queue<T,S> {
	// A basic, unlimited queue

	public UnlimitedQueue(){
	}
	
	public UnlimitedQueue(Integer delayCacheSize) {
		super(delayCacheSize);
	}
	
	public boolean schedulable() {
		return true;
	}
	
	public boolean admittable() {
		return true;
	}

	protected void schedule() {
	}
	
}
